@@ -1,7 +1,7 @@
 utils::globalVariables(".")
 
 
-#to do: save pascal.c more size prudent so it does not have to be compiled 
+
 
 #' Dexter: data analyses for educational and psychological tests.
 #' 
@@ -17,6 +17,14 @@ utils::globalVariables(".")
 #' 
 #' To learn more about dexter, start with the vignettes: `browseVignettes(package="dexter")`  
 #' 
+#' Dexter uses the following global options
+#' \itemize{
+#' \item `dexter.use_tibble` return tibbles instead of data.frames, defaults to FALSE
+#' \item `dexter.progress` show progress bars, defaults to TRUE in interactive sessions
+#' \item `dexter.max_cores` set a maximum number of cores that dexter will use, defaults to the minimum of `Sys.getenv("OMP_THREAD_LIMIT")` and
+#' `getOption("Ncpus")`, otherwise unlimited.
+#' }
+#' 
 "_PACKAGE"
 
 
@@ -279,15 +287,15 @@ touch_rules = function(db, rules)
   
   rules$item_score = as.integer(rules$item_score)
   
-  # check if same options are supplied multiple times, this is the only check not done in conjuntion
+  # check if same options are supplied multiple times, this is the only check not done in conjunction
   # with the existing rules so it has to be gotten out of the way
-  items_with_duplicate_options = unique(rules[duplicated(select(rules,.data$item_id,.data$response)),]$item_id)
+  items_with_duplicate_options = unique(rules[duplicated(select(rules,'item_id', 'response')),]$item_id)
 
   existing_rules = dbGetQuery(db, 'SELECT item_id, response, item_score FROM dxscoring_rules;')
   # remove the no-ops
   rules = dplyr::setdiff(rules, existing_rules)
   
-  existing_opts = existing_rules %>% select(-.data$item_score)
+  existing_opts = existing_rules %>% select(-'item_score')
   
   # new items or responses
   new_rules = rules %>% anti_join(existing_opts, by=c('item_id','response'))
@@ -328,13 +336,13 @@ touch_rules = function(db, rules)
       
       dbExecute_param(db,'INSERT INTO dxscoring_rules(item_id, response, item_score) 
 							                            VALUES(:item_id, :response, :item_score);', 
-				select(new_rules, .data$item_id, .data$response, .data$item_score))
+				select(new_rules, 'item_id', 'response', 'item_score'))
     }
     if(nrow(amended_rules)>0) 
     {
       dbExecute_param(db,'UPDATE dxscoring_rules SET item_score=:item_score 
                       WHERE item_id=:item_id AND response=:response;', 
-                select(amended_rules, .data$item_id, .data$response, .data$item_score))
+                select(amended_rules, 'item_id', 'response', 'item_score'))
     }
   })
   cat(paste0('\nrules_changed: ', nrow(amended_rules), '\nrules_added: ', nrow(new_rules)),'\n')
@@ -413,20 +421,21 @@ add_booklet = function(db, x, booklet_id, auto_add_unknown_rules = FALSE) {
   design = tibble(booklet_id = booklet_id, item_id = names(x), col_order=c(1:ncol(x))) %>%
     inner_join(dbGetQuery(db, "SELECT item_id FROM dxitems;"), by='item_id') %>%
     mutate(item_position = dense_rank(.data$col_order)) %>%
-    select(-.data$col_order)
+    select(-'col_order')
 
   if(nrow(design) == 0) stop('None of the column names in x correspond to known items in your project')
 
   dbTransaction(db,{
     out = list()
-    if (dbExists(db,'SELECT 1 FROM dxbooklets WHERE booklet_id=:b;',tibble(b=booklet_id)) ) 
+    is_existing_booklet = dbExists(db,'SELECT 1 FROM dxbooklets WHERE booklet_id=:b;',tibble(b=booklet_id))
+    if (is_existing_booklet) 
     {
       if(!df_identical(dbGetQuery_param(db,
               'SELECT item_id FROM dxbooklet_design WHERE booklet_id=:b ORDER BY item_position;', 
               tibble(b=booklet_id)),
            tibble(item_id = design$item_id)))
       {
-        stop("There is already a booklet with this ID which has different items or a different item order")
+        stop_("There is already a booklet with this ID which has different items or a different item order")
       }
     } else
     {  
@@ -437,7 +446,7 @@ add_booklet = function(db, x, booklet_id, auto_add_unknown_rules = FALSE) {
       }
       dbExecute_param(db,'INSERT INTO dxbooklet_design(booklet_id, item_id, item_position) 
                           VALUES(:booklet_id,:item_id,:item_position);', 
-				select(design, .data$booklet_id,.data$item_id,.data$item_position))
+				select(design, 'booklet_id', 'item_id', 'item_position'))
     }
                   
     x$booklet_id = booklet_id
@@ -448,18 +457,31 @@ add_booklet = function(db, x, booklet_id, auto_add_unknown_rules = FALSE) {
       message("no column `person_id` provided, automatically generating unique person id's")
     } else
     {
+      x$person_id = as.character(x$person_id)
       known_people = dbGetQuery(db,'SELECT person_id FROM dxpersons;')$person_id
       new_people = setdiff(x$person_id,known_people)
+      if(anyDuplicated(x$person_id))
+        stop_("The column `person_id` has duplicate values, this is not allowed.")
+
+      if(length(new_people) < nrow(x) && is_existing_booklet)
+      {
+        known_admin = dbGetQuery_param(db,"SELECT person_id FROM dxadministrations WHERE booklet_id=:b;",
+                                       tibble(b=booklet_id))$person_id
+        if(length(intersect(known_admin, x$person_id))>0)
+          stop_("One or more person_id's in your data overlap with persons already imported who made the same booklet. This is not allowed. ")
+      }
     }
                   
     dbExecute_param(db,'INSERT INTO dxpersons(person_id) VALUES(:person_id);', tibble(person_id=new_people))
-    # double admin, double items, etc.
     
     dbExecute_param(db,'INSERT INTO dxadministrations(person_id,booklet_id) VALUES(:person_id,:booklet_id);', 
-              select(x,.data$person_id, .data$booklet_id))
+              select(x, 'person_id', 'booklet_id'))
           
-    responses = x[,c(design$item_id, "booklet_id", "person_id")] %>%
-      gather(key='item_id', value='response', -.data$booklet_id, -.data$person_id, na.rm = FALSE)
+    responses = x %>%
+      select(all_of(c(design$item_id, "booklet_id", "person_id"))) %>%
+      pivot_longer(all_of(design$item_id), values_drop_na = FALSE,
+                   names_to='item_id', values_to='response')
+    
             
     responses$response = as.character(responses$response)
     responses$response[is.na(responses$response)] = 'NA'
@@ -472,17 +494,17 @@ add_booklet = function(db, x, booklet_id, auto_add_unknown_rules = FALSE) {
     {
 		  dbExecute_param(db,
 				'INSERT INTO dxscoring_rules(item_id,response,item_score) VALUES(:item_id,:response,0);',
-				select(new_rules, .data$item_id, .data$response))
+				select(new_rules, 'item_id', 'response'))
       out$zero_rules_added = new_rules
     } else if(nrow(new_rules)>0) 
     {
       message('The following responses are not in your rules (showing first 30):\n')
       print(head(as.data.frame(new_rules), 30), row.names=FALSE)
-      stop('unknown responses')
+      stop_('unknown responses')
     }
     dbExecute_param(db,'INSERT INTO dxresponses(booklet_id,person_id,item_id,response) 
                                 VALUES(:booklet_id,:person_id,:item_id,:response);', 
-					select(responses, .data$booklet_id, .data$person_id, .data$item_id, .data$response))
+					select(responses, 'booklet_id', 'person_id', 'item_id', 'response'))
             
     # make this report before we mutilate the colnames  
     columns_ignored = setdiff(names(x), c(design$item_id,'person_id','item_id','booklet_id') )
@@ -602,7 +624,8 @@ add_response_data = function(db, data, design=NULL, missing_value = 'NA', auto_a
     
     # check data
     data_design = distinct(data, .data$booklet_id, .data$item_id)
-    design = semi_join(get_design(db), data_design, by='booklet_id') %>% select(.data$booklet_id, .data$item_id)
+    design = semi_join(get_design(db), data_design, by='booklet_id') %>% 
+      select('booklet_id', 'item_id')
     
     invalid_bk_item = anti_join(data_design, design, by=c('booklet_id','item_id'))
     if(NROW(invalid_bk_item) > 0)
@@ -616,7 +639,7 @@ add_response_data = function(db, data, design=NULL, missing_value = 'NA', auto_a
     administrations = distinct(data,.data$booklet_id, .data$person_id)
     
     data = administrations %>%
-      inner_join(design, by='booklet_id') %>%
+      inner_join(design, by='booklet_id', relationship = "many-to-many") %>%
       left_join(data, by=c('person_id','booklet_id','item_id'))
     
     NA_cnt = sum(is.na(data$response))
@@ -676,7 +699,9 @@ add_response_data = function(db, data, design=NULL, missing_value = 'NA', auto_a
     if(nrow(existing_admin) > 0)
     {
       message('The following person-booklet combination have already been entered into the project (showing first 20)')
-      head(existing_admin, 20) %>% as.data.frame() %>% print(row.names=FALSE)
+      head(existing_admin, 20) %>% 
+        as.data.frame() %>% 
+        print(row.names=FALSE)
       stop('double administrations')
     }
     
@@ -819,6 +844,7 @@ add_person_properties = function(db, person_properties = NULL, default_values =
   check_db(db)
   check_df(person_properties, 'person_id', nullable=TRUE)
   check_list(default_values, nullable=TRUE)
+  
   dbTransaction(db, 
   { 
     existing_props = dbListFields(db, 'dxpersons')
@@ -838,10 +864,9 @@ add_person_properties = function(db, person_properties = NULL, default_values =
     }
     if(!is.null(person_properties))
     {
+      person_properties$person_id = as.character(person_properties$person_id)
       colnames(person_properties) = dbValid_colnames(colnames(person_properties))
-      if(!('person_id' %in% colnames(person_properties))) 
-        stop('column person_id not found in person_properties')
-      
+
       dbCheck_reserved_colnames(setdiff(colnames(person_properties), existing_props))
       
       if(inherits(db,'SQLiteConnection'))
@@ -884,7 +909,7 @@ add_person_properties = function(db, person_properties = NULL, default_values =
 get_rules = function(db)
 {
   check_db(db)
-  dbGetQuery(db, 'SELECT item_id, response, item_score FROM dxscoring_rules ORDER BY item_id, response;')
+  df_format(dbGetQuery(db, 'SELECT item_id, response, item_score FROM dxscoring_rules ORDER BY item_id, response;'))
 }
 
 
@@ -912,7 +937,7 @@ get_booklets = function(db) {
           GROUP BY booklet_id;")
     bk = inner_join(bk,ms,by='booklet_id')
   }
-  bk
+  df_format(bk)
 }
 
 
@@ -1070,10 +1095,11 @@ get_design = function(dataSrc,
     val_col = setdiff(c('booklet_id','item_id','item_position'), c(rows, columns))
 
     design %>%
-        select(.data$item_id,.data$item_position,.data$booklet_id) %>%
-        spread(key = columns, value = val_col, fill = fill) %>%
-        arrange_at(rows) %>%
-        df_format()
+      select('item_id','item_position','booklet_id') %>%
+      pivot_wider(names_from=columns, values_from=val_col, values_fill=fill, names_sort=TRUE) %>%
+      arrange(all_of(rows)) %>%
+      df_format()
+        
   } else
   {
     df_format(design)
@@ -1197,7 +1223,8 @@ design_info = function(dataSrc, predicate = NULL)
 #' Verbal aggression data
 #' 
 #' A data set of self-reported verbal behaviour in different frustrating
-#' situations (Vansteelandt, 2000)
+#' situations (Vansteelandt, 2000). The dataset also contains participants reported gender and scores on the 'anger' questionnaire.
+#' 
 #' 
 #' 
 #' @name verbAggrData
