@@ -43,7 +43,7 @@ tia_tables = function(dataSrc, predicate = NULL, type=c('raw','averaged','compar
   {
     items$item_id = as.character(items$item_id)
     items = inner_join(
-      select(items, -.data$max_score),
+      select(items, -'max_score'),
       dbGetQuery(dataSrc, 'SELECT item_id, MAX(item_score) AS max_score FROM dxscoring_rules GROUP BY item_id;'),
       by='item_id')
   } 
@@ -67,11 +67,18 @@ tia_tables = function(dataSrc, predicate = NULL, type=c('raw','averaged','compar
     mutate_if(is.factor, as.character) %>%
     df_format()
   
+  
+  # for presentation purposes, the sd of the item score should be divided by n-1
+  # since that is the default in R.
+  # Note that this happens AFTER alpha is computed and BEFORE any sd's are grouped over booklets
+  
+  items$sd_score = sqrt(items$n_persons/(items$n_persons-1)) * items$sd_score
+  
   # different views of item statistics
   if(type=='raw')
   {
-    out$items = select(items, .data$booklet_id, .data$item_id, .data$mean_score, .data$sd_score, 
-                           .data$max_score, .data$pvalue, .data$rit, .data$rir, .data$n_persons) %>%
+    out$items = select(items, 'booklet_id', 'item_id', 'mean_score', 'sd_score', 
+                           'max_score', 'pvalue', 'rit', 'rir', 'n_persons') %>%
       mutate_if(is.factor, as.character) %>%
       df_format()
     
@@ -89,7 +96,7 @@ tia_tables = function(dataSrc, predicate = NULL, type=c('raw','averaged','compar
                  n_persons = sum(.data$n_persons)) %>%
       ungroup() %>%
       mutate_if(is.factor, as.character) %>%
-      rename(mean_score=.data$w_mean_score) %>%
+      rename(mean_score = 'w_mean_score') %>%
       df_format()
   } else
   {
@@ -97,45 +104,45 @@ tia_tables = function(dataSrc, predicate = NULL, type=c('raw','averaged','compar
     
     out$items = list(
       pvalue = items %>% 
-        select(.data$booklet_id,.data$item_id,.data$pvalue) %>% 
-        spread(key=.data$booklet_id, value=.data$pvalue),
+        select('booklet_id', 'item_id', 'pvalue') %>% 
+        pivot_wider(names_from='booklet_id', values_from='pvalue', names_sort=TRUE),
       
       rit = items %>% 
-        select(.data$booklet_id,.data$item_id,.data$rit) %>% 
-        spread(key=.data$booklet_id,value=.data$rit),
+        select('booklet_id', 'item_id', 'rit') %>% 
+        pivot_wider(names_from='booklet_id', values_from='rit', names_sort=TRUE),
       
       rir = items %>% 
-        select(.data$booklet_id,.data$item_id,.data$rir) %>% 
-        spread(key=.data$booklet_id,value=.data$rir)
+        select('booklet_id', 'item_id', 'rir') %>% 
+        pivot_wider(names_from='booklet_id', values_from='rir', names_sort=TRUE)
     )
   }
   
   if(distractor)
   {
-    d = respData$x |>
-      mutate(bs=.data$booklet_score-.data$item_score) |>
-      group_by(.data$booklet_id, .data$item_id, .data$response) |>
-      summarise(n=n(), rbsum=sum(.data$bs), rb2sum=sum(.data$bs^2), .groups='drop_last') |>
+    d = respData$x %>%
+      mutate(bs=.data$booklet_score-.data$item_score) %>%
+      group_by(.data$booklet_id, .data$item_id, .data$response) %>%
+      summarise(item_score=first(.data$item_score), n=n(), rbsum=sum(.data$bs), rb2sum=sum(.data$bs^2), .groups='drop_last') %>%
       mutate(N = sum(.data$n), 
              bmean = sum(.data$rbsum)/.data$N, 
              b2mean = sum(.data$rb2sum)/.data$N,
              rvalue = .data$n/.data$N,
              rar = (.data$rbsum/.data$N - .data$rvalue*.data$bmean)/
-                   sqrt(.data$rvalue*(1-.data$rvalue)*(.data$b2mean - .data$bmean^2)) ) |>
+                   sqrt(.data$rvalue*(1-.data$rvalue)*(.data$b2mean - .data$bmean^2)) ) %>%
       ungroup() 
     
     # type==compared makes little sense to me for distractors, so treated same as raw
     if(type=='averaged')
     {
       d = d %>%
-        group_by(.data$item_id, .data$response) %>%
+        group_by(.data$item_id, .data$response, .data$item_score) %>%
         summarise(n=sum(.data$n),
-                  rvalue=weighted.mean(.data$rvalue,.data$N),
-                  rar=weighted.mean(.data$rar,.data$N, na.rm=TRUE)) %>%
+                  rvalue = weighted.mean(.data$rvalue,.data$N),
+                  rar = weighted.mean(.data$rar,.data$N, na.rm=TRUE)) %>%
         ungroup()
     } else
     {
-      d = select(d, .data$booklet_id, .data$item_id, .data$response, .data$n, .data$rvalue, .data$rar)
+      d = select(d, 'booklet_id', 'item_id', 'response', 'item_score', 'n', 'rvalue', 'rar')
     }
     
     out$distractors = d %>%
