@@ -2,6 +2,9 @@ context('test plausible_values')
 
 library(dplyr)
 
+
+RcppArmadillo::armadillo_throttle_cores(1)
+
 test_that('populations work',{
   db = open_project('../verbAggression.db')
   
@@ -26,4 +29,5 @@ test_that('populations work',{
   
   dbDisconnect(db)
 })
-  
\ No newline at end of file
+  
+RcppArmadillo::armadillo_reset_cores()
